# Licensed under a 3-clause BSD style license - see LICENSE.rst

"""
BSD-licensed HEALPix for Astropy.
"""

# Packages may add whatever they like to this file, but
# should keep this content at the top.
# ----------------------------------------------------------------------------
from ._astropy_init import *   # noqa
# ----------------------------------------------------------------------------

from .high_level import *  # noqa
from .core import *  # noqa
